Client

Struct Client 

pub struct Client<B, T: Transport<B>> {
    pub transport: T,
    pub phantom_body: PhantomData<B>,
    pub endpoint: Cow<'static, str>,
    pub authorization: Option<HeaderValue>,
    pub extra_headers: HeaderMap,
}

Fields

transport: Tphantom_body: PhantomData<B>endpoint: Cow<'static, str>authorization: Option<HeaderValue>extra_headers: HeaderMap

Implementations

Source

impl Client<Body, HttpsTransport>

pub fn new_https_client( endpoint: Cow<'static, str>, ) -> Client<Body, HttpsTransport>

Create a new client using transport::HttpsTransport and hyper::Body.

pub fn new_https_retry_client( endpoint: Cow<'static, str>, retry_config: RetryConfig, ) -> Client<Vec<u8>, HttpsRetryTransport>

Create a new client using transport::HttpsRetryTransport and hyper::Body.

Source

impl<B, T: Transport<B>> Client<B, T>

pub fn http_request_builder(&self) -> Builder

Create a new request builder based on this client.

This should always be used as the base builder, since it includes the authorization and extra headers, and may include more parameters in the future.